pilas.imagenes

Package pilas :: Module imagenes |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.imagenes

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10
    11 -def cargar(ruta):
    12      """Intenta cargar la imagen indicada por el argumento ``ruta``.
    13
    14      Por ejemplo::
    15
    16          import pilas
    17
    18          imagen = pilas.imagenes.cargar("mi_archivo.png")
    19
    20      En caso de éxito retorna el objeto Image, que se puede asignar
    21      a un Actor.
    22
    23      El directorio de búsqueda de la imagen sigue el siguiente orden:
    24
    25          * primero busca en el directorio actual.
    26          * luego en 'data'.
    27          * por último en el directorio estándar de la biblioteca.
    28
    29      En caso de error genera una excepción de tipo IOError.
    30      """
    31
    32      if not pilas.mundo:
    33          mensaje = "Tiene que invocar a la funcion ``pilas.iniciar()`` para comenzar."
    34          print mensaje
    35          raise Exception(mensaje)
    36
    37      ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
    38      return pilas.mundo.motor.cargar_imagen(ruta)
    39
    40 -def cargar_grilla(ruta, columnas=1, filas=1):
    41      """Representa una grilla de imagenes con varios cuadros de animación.
    42
    43      Una grilla es un objeto que se tiene que inicializar con la ruta
    44      a una imagen, la cantidad de columnas y filas.
    45
    46      Por ejemplo, si tenemos una grilla con 2 columnas y 3 filas
    47      podemos asociarla a un actor de la siguiente manera::
    48
    49          grilla = pilas.imagenes.cargar_grilla("animacion.png", 2, 3)
    50          grilla.asignar(actor)
    51
    52      Entonces, a partir de ahora nuestro actor muestra solamente un
    53      cuadro de toda la grilla.
    54
    55      Si quieres avanzar la animacion tienes que modificar el objeto
    56      grilla y asignarlo nuevamente al actor::
    57
    58          grilla.avanzar()
    59          grilla.asignar(actor)
    60      """
    61      if not pilas.mundo:
    62          mensaje = "Tiene que invocar a la funcion ``pilas.iniciar()`` para comenzar."
    63          print mensaje
    64          raise Exception(mensaje)
    65
    66      ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
    67      return pilas.mundo.motor.obtener_grilla(ruta, columnas, filas)
    68
    69 -def cargar_lienzo():
    70      """Representa un rectangulo (inicialmente transparente) para dibujar."""
    71      return pilas.mundo.motor.obtener_lienzo()
    72
    73 -def cargar_superficie(ancho, alto):
    74      return pilas.mundo.motor.obtener_superficie(ancho, alto)
    75
    76  cargar_imagen = cargar
    77